@@ -23,6 +23,7 @@
 #include <gconf/gconf-client.h>
 #include <games-gconf.h>
 #include <games-frame.h>
+#include <games-files.h>
 
 /* Define a sensible alternative to ngettext if we don't have it. Note that
  * this is only sensible in the context of same-gnome. */
@@ -441,7 +442,6 @@ load_scenario (char *fname)
 			   "Please check your Same GNOME installation."), fn);
 
 		gtk_dialog_set_default_response (GTK_DIALOG (box), GTK_RESPONSE_OK);
-                gtk_dialog_set_has_separator (GTK_DIALOG (box), FALSE);
 		gtk_dialog_run (GTK_DIALOG (box));
 		gtk_widget_destroy (box);
                 /* We may not have called gtk_main yet, but if we do we want
@@ -473,7 +473,6 @@ load_scenario (char *fname)
 		
 		gtk_dialog_set_default_response (GTK_DIALOG (box),
 						 GTK_RESPONSE_OK);
-                gtk_dialog_set_has_separator (GTK_DIALOG (box), FALSE);
 		gtk_dialog_run (GTK_DIALOG (box));
 		gtk_widget_destroy (box);
                 /* We may not have called gtk_main yet, but if we do we want
@@ -555,46 +554,40 @@ set_selection (GtkTreeSelection *selection, gpointer data)
 	gconf_client_set_string (conf_client, KEY_TILESET, filename, NULL);
 }
 
+static void fill_list_foreach (gchar * string, GtkListStore * list)
+{
+        GtkTreeIter iter;
+	gchar *name;
+	gchar *suffix;
+	
+	/* We strip any trailing suffix, any -sync suffix
+	 * and convert '_' to ' '. This is brutal code. */
+	name = g_strdup (string);
+	suffix = g_strrstr (name,".");
+	if (suffix) *suffix = '\0';
+	suffix = g_strrstr (name,"-sync");
+	if (suffix) *suffix = '\0';
+	suffix = name;
+	while (*suffix) {
+		if (*suffix == '_') *suffix = ' ';
+		suffix++;
+	}
+	
+	gtk_list_store_append (list, &iter);
+	gtk_list_store_set (list, &iter, 0, name, 1, g_strdup (string), -1);
+} 
+
 static void
 fill_list (GtkListStore *list)
 {
-        GDir * dir;
-        gchar * filename;
-        GtkTreeIter iter;
+	GamesFileList * filelist;
 	
-	dir = g_dir_open (PIXMAPDIR, 0, NULL);
-
-	if (!dir)
-		return;
+	filelist = games_file_list_new_images (PIXMAPDIR, NULL);
+	games_file_list_transform_basename (filelist);
 	
-	while ((filename = g_strdup (g_dir_read_name (dir))) != NULL) {
-		gchar *name;
-                gchar *suffix;
-                gchar *path = NULL;
-                path = g_build_filename (PIXMAPDIR, filename, NULL);
-                if (!g_file_test (path, G_FILE_TEST_IS_REGULAR)) {
-                        g_free (filename);
-			g_free (path);
-                        continue;
-                }
+	games_file_list_for_each (filelist, (GFunc) fill_list_foreach, list);
 
-                /* We strip any trailing suffix, any -sync suffix
-                 * and convert '_' to ' '. This is brutal code. */
-                name = g_strdup (filename);
-                suffix = g_strrstr (name,".");
-                if (suffix) *suffix = '\0';
-                suffix = g_strrstr (name,"-sync");
-                if (suffix) *suffix = '\0';
-                suffix = name;
-                while (*suffix) {
-                        if (*suffix == '_') *suffix = ' ';
-                        suffix++;
-                }
-                
-                gtk_list_store_append (list, &iter);
-                gtk_list_store_set (list, &iter, 0, name, 1, filename, -1);
-	}
-	g_dir_close (dir);
+	g_object_unref (filelist);
 }
 
 static void
@@ -711,7 +704,7 @@ game_about_callback (GtkWidget *widget, void *data)
                 NULL
         };
         /* Translator credits */
-        gchar *translator_credits = _("translator_credits");
+        gchar *translator_credits = _("translator-credits");
 
 	if (about) {
 		gtk_window_present (GTK_WINDOW (about));
@@ -737,7 +730,7 @@ game_about_callback (GtkWidget *widget, void *data)
 				 _("Original idea from KDE's same game "
 				   "program."),				 (const char **)authors,
 				 (const char **)documenters,
-				 strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
+				 strcmp (translator_credits, "translator-credits") != 0 ? translator_credits : NULL,
                                  pixbuf);
 	if (pixbuf != NULL)
 		g_object_unref (pixbuf);
